##  Building up SAP BTP as a Strategic Platform
Use SAP LeanIX to plan, document, and build BTP as your organization's strategic platform, aligned with your business goals. This involves mapping out dependencies on other projects, for example, those focused on adoption and setting up basic services like HANA Cloud for app development or common monitoring services.
![Diagram Showing Initiatives That Leverage SAP BTP To Adhere to SAP’s Clean Core Approach and Towards Resilient Applications](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274390807a4410149e79ff2dc79666a5_LowRes.png)
Diagram Showing Initiatives That Leverage SAP BTP To Adhere to SAP’s Clean Core Approach and Towards Resilient Applications
